const { execSync } = require("child_process");
const colors = require("colors");
const render_site = require("./render-site.js");
const rename_style = require("./rename-style.js");
const build_style = require("./build-style.js");
const notify = require("./notify");
const clear_cache = require("./clear-cache");
const timestamp = require("./timestamp");

async function build_html(sitemap, output_dir) {
	clear_cache();
	render_site(sitemap, output_dir);
}

async function build_html_and_css({sitemap, output_dir, scss_entrypoint}) {
	try {
		console.log("Building...".yellow);
		const time_start = Date.now();
		await build_style({output_dir, scss_entrypoint});
		await build_html(sitemap, output_dir);
		rename_style({output_dir});
		const time_passed = Date.now() - time_start;
		console.log(
			timestamp().green.bold,
			`✔️ Build done (${time_passed}ms)`.green
		);
		notify("ok", "Build done", 250);
	} catch (e) {
		console.error(e.formatted || e);
		notify("error", "Build error", 5000);
	}
}

module.exports = build_html_and_css;
